==> argile-2.0.0.tar.gz: argile-2.0.0/compiler/parser.h <==
/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_WORD = 258,
     T_OP = 259,
     T_SYN_OP = 260,
     T_PAR_OP = 261,
     T_INT_HEX = 262,
     T_INT_DEC = 263,
     T_INT_OCT = 264,
     T_INT_BIN = 265,
     T_REAL = 266,
     T_TEXT = 267,
     T_SYN_BEG = 268,
     T_SYN_END = 269,
     T_CODE_BEG = 270,
     T_CODE_END = 271,
     T_SUB_BEG = 272,
     T_SUB_END = 273,
     T_CALL_END = 274,
     T_PAR_BEG = 275,
     T_PAR_INIT = 276,
     T_PAR_SEP = 277,
     T_PAR_END = 278,
     T_OPT_BEG = 279,
     T_OPT_END = 280,
     T_ENM_BEG = 281,
     T_ENM_SEP = 282,
     T_ENM_END = 283,
     T_LST_BEG = 284,
     T_LST_SEP = 285,
     T_LST_BND = 286,
     T_LST_END = 287,
     T_END = 288
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 46 "./parser.y"

  char               *string;
  argile_text_t      *text;
  argile_list_t      *call_list;
  argile_call_t      *call;
  argile_list_t      *match_list;
  argile_match_t     *match;
  argile_cons_t      *cons;
  argile_list_t      *syn_list;
  argile_syntax_t    *syntax;
  argile_syn_param_t *synparm;
  argile_list_t      *synparm_list;
  argile_syn_list_t  *synlst;
  argile_list_t      *enm_list;



/* Line 2068 of yacc.c  */
#line 101 "parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE argile_yylval;

#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

extern YYLTYPE argile_yylloc;

==> argile-2.1.0.tar.gz: argile-2.1.0/compiler/parser.h <==
/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_WORD = 258,
     T_OP = 259,
     T_SYN_OP = 260,
     T_PAR_OP = 261,
     T_INT_HEX = 262,
     T_INT_DEC = 263,
     T_INT_OCT = 264,
     T_INT_BIN = 265,
     T_REAL = 266,
     T_TEXT = 267,
     T_SYN_BEG = 268,
     T_SYN_END = 269,
     T_CODE_BEG = 270,
     T_CODE_END = 271,
     T_SUB_BEG = 272,
     T_SUB_END = 273,
     T_CALL_END = 274,
     T_PAR_BEG = 275,
     T_PAR_INIT = 276,
     T_PAR_SEP = 277,
     T_PAR_END = 278,
     T_OPT_BEG = 279,
     T_OPT_END = 280,
     T_ENM_BEG = 281,
     T_ENM_SEP = 282,
     T_ENM_END = 283,
     T_LST_BEG = 284,
     T_LST_SEP = 285,
     T_LST_BND = 286,
     T_LST_END = 287,
     T_END = 288
   };
#endif



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 46 "./parser.y"

  char               *string;
  argile_text_t      *text;
  argrt_list_t       *call_list;
  argile_call_t      *call;
  argrt_list_t       *match_list;
  argile_match_t     *match;
  argile_cons_t      *cons;
  argrt_list_t       *syn_list;
  argile_syntax_t    *syntax;
  argile_syn_param_t *synparm;
  argrt_list_t       *synparm_list;
  argile_syn_list_t  *synlst;
  argrt_list_t       *enm_list;



/* Line 2068 of yacc.c  */
#line 101 "parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE argile_yylval;

#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

extern YYLTYPE argile_yylloc;
